@@ -52,6 +52,7 @@
 #include "photos-single-item-job.h"
 #include "photos-source-manager.h"
 #include "photos-tracker-extract-priority.h"
+#include "photos-utils.h"
 
 
 struct _PhotosApplicationPrivate
@@ -81,6 +82,14 @@ struct _PhotosApplicationPrivate
   guint32 activation_timestamp;
 };
 
+enum
+{
+  MINERS_CHANGED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 static void photos_application_search_context_iface_init (PhotosSearchContextInterface *iface);
 
 
@@ -390,6 +399,7 @@ photos_application_refresh_db (GObject *source_object, GAsyncResult *res, gpoint
   PhotosApplicationRefreshData *data;
 
   priv->miners_running = g_list_remove (priv->miners_running, miner);
+  g_signal_emit (self, signals[MINERS_CHANGED], 0, priv->miners_running);
 
   error = NULL;
   if (!gom_miner_call_refresh_db_finish (miner, res, &error))
@@ -418,15 +428,17 @@ photos_application_refresh_miner_now (PhotosApplication *self, GomMiner *miner)
 {
   PhotosApplicationPrivate *priv = self->priv;
   GCancellable *cancellable;
+  const gchar *const index_types[] = {"photos", NULL};
 
   if (g_getenv ("PHOTOS_DISABLE_MINERS") != NULL)
     goto out;
 
   priv->miners_running = g_list_prepend (priv->miners_running, g_object_ref (miner));
+  g_signal_emit (self, signals[MINERS_CHANGED], 0, priv->miners_running);
 
   cancellable = g_cancellable_new ();
   g_object_set_data_full (G_OBJECT (miner), "cancellable", cancellable, g_object_unref);
-  gom_miner_call_refresh_db (miner, cancellable, photos_application_refresh_db, g_object_ref (self));
+  gom_miner_call_refresh_db (miner, index_types, cancellable, photos_application_refresh_db, g_object_ref (self));
 
  out:
   return G_SOURCE_REMOVE;
@@ -555,6 +567,42 @@ photos_application_stop_miners (PhotosApplication *self)
 }
 
 
+static void
+photos_application_theme_changed (GtkSettings *settings)
+{
+  static GtkCssProvider *provider;
+  GdkScreen *screen;
+  gchar *theme;
+
+  g_object_get (settings, "gtk-theme-name", &theme, NULL);
+  screen = gdk_screen_get_default ();
+
+  if (g_strcmp0 (theme, "Adwaita") == 0)
+    {
+      if (provider == NULL)
+        {
+          GFile *file;
+
+          provider = gtk_css_provider_new ();
+          file = g_file_new_for_uri ("resource:///org/gnome/photos/Adwaita.css");
+          gtk_css_provider_load_from_file (provider, file, NULL);
+          g_object_unref (file);
+        }
+
+      gtk_style_context_add_provider_for_screen (screen,
+                                                 GTK_STYLE_PROVIDER (provider),
+                                                 GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    }
+  else if (provider != NULL)
+    {
+      gtk_style_context_remove_provider_for_screen (screen, GTK_STYLE_PROVIDER (provider));
+      g_clear_object (&provider);
+    }
+
+  g_free (theme);
+}
+
+
 static void
 photos_application_tracker_clear_rdf_types (GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -728,6 +776,12 @@ photos_application_startup (GApplication *application)
   GrlRegistry *registry;
   GtkSettings *settings;
   GVariant *state;
+  const gchar *fullscreen_accels[2] = {"F11", NULL};
+  const gchar *gear_menu_accels[2] = {"F10", NULL};
+  const gchar *print_current_accels[2] = {"<Primary>p", NULL};
+  const gchar *quit_accels[2] = {"<Primary>q", NULL};
+  const gchar *search_accels[2] = {"<Primary>f", NULL};
+  const gchar *select_all_accels[2] = {"<Primary>a", NULL};
 
   G_APPLICATION_CLASS (photos_application_parent_class)
     ->startup (application);
@@ -750,6 +804,8 @@ photos_application_startup (GApplication *application)
 
   settings = gtk_settings_get_default ();
   g_object_set (settings, "gtk-application-prefer-dark-theme", TRUE, NULL);
+  g_signal_connect (settings, "notify::gtk-theme-name", G_CALLBACK (photos_application_theme_changed), NULL);
+  photos_application_theme_changed (settings);
 
   priv->facebook_miner = gom_miner_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
                                                            G_DBUS_PROXY_FLAGS_NONE,
@@ -850,12 +906,12 @@ photos_application_startup (GApplication *application)
   g_action_map_add_action (G_ACTION_MAP (self), G_ACTION (action));
   g_object_unref (action);
 
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "<Primary>q", "app.quit", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "F11", "app.fullscreen", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "F10", "app.gear-menu", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "<Primary>p", "app.print-current", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "<Primary>f", "app.search", NULL);
-  gtk_application_add_accelerator (GTK_APPLICATION (self), "<Primary>a", "app.select-all", NULL);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.quit", quit_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.fullscreen", fullscreen_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.gear-menu", gear_menu_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.print-current", print_current_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.search", search_accels);
+  gtk_application_set_accels_for_action (GTK_APPLICATION (self), "app.select-all", select_all_accels);
 }
 
 
@@ -928,6 +984,8 @@ photos_application_init (PhotosApplication *self)
 
   eog_debug_init ();
 
+  photos_utils_ensure_builtins ();
+
   priv->search_provider = photos_search_provider_new ();
   g_signal_connect_swapped (priv->search_provider,
                             "activate-result",
@@ -957,7 +1015,15 @@ photos_application_class_init (PhotosApplicationClass *class)
   application_class->shutdown = photos_application_shutdown;
   application_class->startup = photos_application_startup;
 
-  /* TODO: Add miners-changed signal */
+  signals[MINERS_CHANGED] = g_signal_new ("miners-changed",
+                                          G_TYPE_FROM_CLASS (class),
+                                          G_SIGNAL_RUN_LAST,
+                                          G_STRUCT_OFFSET (PhotosApplicationClass, miners_changed),
+                                          NULL, /* accumulator */
+                                          NULL, /* accu_data */
+                                          g_cclosure_marshal_VOID__POINTER,
+                                          G_TYPE_NONE,
+                                          0);
 }
 
 
@@ -973,11 +1039,17 @@ photos_application_new (void)
 {
   return g_object_new (PHOTOS_TYPE_APPLICATION,
                        "application-id", "org.gnome." PACKAGE_NAME,
-                       "flags", G_APPLICATION_IS_SERVICE,
                        NULL);
 }
 
 
+GList *
+photos_application_get_miners_running (PhotosApplication *self)
+{
+  return self->priv->miners_running;
+}
+
+
 gint
 photos_application_get_scale_factor (PhotosApplication *self)
 {
