@@ -40,6 +40,7 @@
 #include "photos-delete-item-job.h"
 #include "photos-filterable.h"
 #include "photos-icons.h"
+#include "photos-print-notification.h"
 #include "photos-print-operation.h"
 #include "photos-query.h"
 #include "photos-search-context.h"
@@ -105,9 +106,10 @@ static guint signals[LAST_SIGNAL] = { 0 };
 static void photos_base_item_filterable_iface_init (PhotosFilterableInterface *iface);
 
 
-G_DEFINE_TYPE_WITH_CODE (PhotosBaseItem, photos_base_item, G_TYPE_OBJECT,
-                         G_ADD_PRIVATE (PhotosBaseItem)
-                         G_IMPLEMENT_INTERFACE (PHOTOS_TYPE_FILTERABLE, photos_base_item_filterable_iface_init));
+G_DEFINE_ABSTRACT_TYPE_WITH_CODE (PhotosBaseItem, photos_base_item, G_TYPE_OBJECT,
+                                  G_ADD_PRIVATE (PhotosBaseItem)
+                                  G_IMPLEMENT_INTERFACE (PHOTOS_TYPE_FILTERABLE,
+                                                         photos_base_item_filterable_iface_init));
 
 
 static GThreadPool *create_thumbnail_pool;
@@ -853,6 +855,11 @@ photos_base_item_print_load (GObject *source_object, GAsyncResult *res, gpointer
                          g_object_ref (self),
                          (GClosureNotify) g_object_unref,
                          G_CONNECT_SWAPPED);
+
+
+  /* It is self managing. */
+  photos_print_notification_new (print_op);
+
   gtk_print_operation_run (print_op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, toplevel, NULL);
 
  out:
@@ -1207,10 +1214,10 @@ photos_base_item_get_resource_urn (PhotosBaseItem *self)
 }
 
 
-const gchar *
-photos_base_item_get_source_name (PhotosBaseItem *self)
+GtkWidget *
+photos_base_item_get_source_widget (PhotosBaseItem *self)
 {
-  return PHOTOS_BASE_ITEM_GET_CLASS (self)->get_source_name(self);
+  return PHOTOS_BASE_ITEM_GET_CLASS (self)->get_source_widget(self);
 }
 
 
