@@ -30,7 +30,6 @@
 #include <gfbgraph/gfbgraph-goa-authorizer.h>
 #include <gio/gio.h>
 #include <glib.h>
-#include <glib/gi18n.h>
 #include <goa/goa.h>
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
 
@@ -47,7 +46,13 @@ struct _PhotosFacebookItemPrivate
 };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosFacebookItem, photos_facebook_item, PHOTOS_TYPE_BASE_ITEM);
+G_DEFINE_TYPE_WITH_CODE (PhotosFacebookItem, photos_facebook_item, PHOTOS_TYPE_BASE_ITEM,
+                         G_ADD_PRIVATE (PhotosFacebookItem)
+                         photos_utils_ensure_extension_points ();
+                         g_io_extension_point_implement (PHOTOS_BASE_ITEM_EXTENSION_POINT_NAME,
+                                                         g_define_type_id,
+                                                         "facebook",
+                                                         0));
 
 
 static GFBGraphPhoto *
@@ -185,10 +190,18 @@ photos_facebook_item_download (PhotosBaseItem *item, GCancellable *cancellable,
 }
 
 
-static const gchar *
-photos_facebook_item_get_source_name (PhotosBaseItem *item)
+static GtkWidget *
+photos_facebook_item_get_source_widget (PhotosBaseItem *item)
 {
-  return _("Facebook");
+  PhotosFacebookItem *self = PHOTOS_FACEBOOK_ITEM (item);
+  GtkWidget *source_widget;
+  const gchar *name;
+
+  name = photos_utils_get_provider_name (self->priv->src_mngr, item);
+  source_widget = gtk_link_button_new_with_label ("https://www.facebook.com/", name);
+  gtk_widget_set_halign (source_widget, GTK_ALIGN_START);
+
+  return source_widget;
 }
 
 
@@ -215,10 +228,12 @@ static void
 photos_facebook_item_constructed (GObject *object)
 {
   PhotosFacebookItem *self = PHOTOS_FACEBOOK_ITEM (object);
+  const gchar *name;
 
   G_OBJECT_CLASS (photos_facebook_item_parent_class)->constructed (object);
 
-  photos_base_item_set_default_app_name (PHOTOS_BASE_ITEM (self), _("Facebook"));
+  name = photos_utils_get_provider_name (self->priv->src_mngr, PHOTOS_BASE_ITEM (self));
+  photos_base_item_set_default_app_name (PHOTOS_BASE_ITEM (self), name);
 }
 
 
@@ -260,16 +275,6 @@ photos_facebook_item_class_init (PhotosFacebookItemClass *class)
   object_class->dispose = photos_facebook_item_dispose;
   base_item_class->create_thumbnail = photos_facebook_item_create_thumbnail;
   base_item_class->download = photos_facebook_item_download;
-  base_item_class->get_source_name = photos_facebook_item_get_source_name;
+  base_item_class->get_source_widget = photos_facebook_item_get_source_widget;
   base_item_class->open = photos_facebook_item_open;
 }
-
-
-PhotosBaseItem *
-photos_facebook_item_new (TrackerSparqlCursor *cursor)
-{
-  return g_object_new (PHOTOS_TYPE_FACEBOOK_ITEM,
-                       "cursor", cursor,
-                       "failed-thumbnailing", FALSE,
-                       NULL);
-}
