@@ -29,7 +29,6 @@
 
 #include <gio/gio.h>
 #include <glib.h>
-#include <glib/gi18n.h>
 #include <goa/goa.h>
 #include <grilo.h>
 #include <libgnome-desktop/gnome-desktop-thumbnail.h>
@@ -47,7 +46,13 @@ struct _PhotosFlickrItemPrivate
 };
 
 
-G_DEFINE_TYPE_WITH_PRIVATE (PhotosFlickrItem, photos_flickr_item, PHOTOS_TYPE_BASE_ITEM);
+G_DEFINE_TYPE_WITH_CODE (PhotosFlickrItem, photos_flickr_item, PHOTOS_TYPE_BASE_ITEM,
+                         G_ADD_PRIVATE (PhotosFlickrItem)
+                         photos_utils_ensure_extension_points ();
+                         g_io_extension_point_implement (PHOTOS_BASE_ITEM_EXTENSION_POINT_NAME,
+                                                         g_define_type_id,
+                                                         "flickr",
+                                                         0));
 
 
 typedef struct _PhotosFlickrItemSyncData PhotosFlickrItemSyncData;
@@ -189,7 +194,7 @@ photos_flickr_item_create_thumbnail (PhotosBaseItem *item, GCancellable *cancell
   local_dir = g_path_get_dirname (local_path);
   g_mkdir_with_parents (local_dir, 0700);
 
-  g_debug ("Downloading %s from Flickr to %s", uri, local_path);
+  g_debug ("Downloading %s from Flickr to %s", thumbnail_uri, local_path);
   if (!g_file_copy (remote_file,
                     local_file,
                     G_FILE_COPY_ALL_METADATA | G_FILE_COPY_OVERWRITE,
@@ -270,10 +275,18 @@ photos_flickr_item_download (PhotosBaseItem *item, GCancellable *cancellable, GE
 }
 
 
-static const gchar *
-photos_flickr_item_get_source_name (PhotosBaseItem *item)
+static GtkWidget *
+photos_flickr_item_get_source_widget (PhotosBaseItem *item)
 {
-  return _("Flickr");
+  PhotosFlickrItem *self = PHOTOS_FLICKR_ITEM (item);
+  GtkWidget *source_widget;
+  const gchar *name;
+
+  name = photos_utils_get_provider_name (self->priv->src_mngr, item);
+  source_widget = gtk_link_button_new_with_label ("https://www.flickr.com/", name);
+  gtk_widget_set_halign (source_widget, GTK_ALIGN_START);
+
+  return source_widget;
 }
 
 
@@ -317,10 +330,12 @@ static void
 photos_flickr_item_constructed (GObject *object)
 {
   PhotosFlickrItem *self = PHOTOS_FLICKR_ITEM (object);
+  const gchar *name;
 
   G_OBJECT_CLASS (photos_flickr_item_parent_class)->constructed (object);
 
-  photos_base_item_set_default_app_name (PHOTOS_BASE_ITEM (self), _("Flickr"));
+  name = photos_utils_get_provider_name (self->priv->src_mngr, PHOTOS_BASE_ITEM (self));
+  photos_base_item_set_default_app_name (PHOTOS_BASE_ITEM (self), name);
 }
 
 
@@ -362,16 +377,6 @@ photos_flickr_item_class_init (PhotosFlickrItemClass *class)
   object_class->dispose = photos_flickr_item_dispose;
   base_item_class->create_thumbnail = photos_flickr_item_create_thumbnail;
   base_item_class->download = photos_flickr_item_download;
-  base_item_class->get_source_name = photos_flickr_item_get_source_name;
+  base_item_class->get_source_widget = photos_flickr_item_get_source_widget;
   base_item_class->open = photos_flickr_item_open;
 }
-
-
-PhotosBaseItem *
-photos_flickr_item_new (TrackerSparqlCursor *cursor)
-{
-  return g_object_new (PHOTOS_TYPE_FLICKR_ITEM,
-                       "cursor", cursor,
-                       "failed-thumbnailing", FALSE,
-                       NULL);
-}
