@@ -28,6 +28,7 @@
 #include <gtk/gtk.h>
 
 #include "photos-searchbar.h"
+#include "photos-view-model.h"
 
 G_BEGIN_DECLS
 
@@ -78,8 +79,12 @@ gboolean               photos_main_toolbar_handle_event           (PhotosMainToo
 
 gboolean               photos_main_toolbar_is_focus               (PhotosMainToolbar *self);
 
+void                   photos_main_toolbar_reset_toolbar_mode     (PhotosMainToolbar *self);
+
 void                   photos_main_toolbar_set_stack              (PhotosMainToolbar *self, GtkStack *stack);
 
+void                   photos_main_toolbar_set_view_model         (PhotosMainToolbar *self, PhotosViewModel *model);
+
 G_END_DECLS
 
 #endif /* PHOTOS_MAIN_TOOLBAR_H */
