@@ -29,6 +29,7 @@
 #include <glib/gi18n.h>
 #include <libgd/gd.h>
 
+#include "photos-enums.h"
 #include "photos-icons.h"
 #include "photos-item-manager.h"
 #include "photos-preview-model.h"
@@ -47,6 +48,9 @@ struct _PhotosPreviewNavButtonsPrivate
   GtkWidget *preview_view;
   GtkWidget *toolbar_widget;
   PhotosBaseManager *item_mngr;
+  PhotosPreviewAction action;
+  gboolean enable_next;
+  gboolean enable_prev;
   gboolean hover;
   gboolean visible;
   guint auto_hide_id;
@@ -56,10 +60,20 @@ struct _PhotosPreviewNavButtonsPrivate
 enum
 {
   PROP_0,
+  PROP_ENABLE_NEXT,
+  PROP_ENABLE_PREVIOUS,
   PROP_OVERLAY,
   PROP_PREVIEW_VIEW
 };
 
+enum
+{
+  ACTIVATED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0 };
+
 
 G_DEFINE_TYPE_WITH_PRIVATE (PhotosPreviewNavButtons, photos_preview_nav_buttons, G_TYPE_OBJECT);
 
@@ -207,12 +221,12 @@ photos_preview_nav_buttons_update_favorite (PhotosPreviewNavButtons *self, gbool
   if (favorite)
     {
       favorite_label = g_strdup (_("Remove from favorites"));
-      gtk_style_context_add_class (context, "documents-favorite");
+      gtk_style_context_add_class (context, "photos-favorite");
     }
   else
     {
       favorite_label = g_strdup (_("Add to favorites"));
-      gtk_style_context_remove_class (context, "documents-favorite");
+      gtk_style_context_remove_class (context, "photos-favorite");
     }
 
   gtk_widget_reset_style (priv->favorite_button);
@@ -227,34 +241,33 @@ photos_preview_nav_buttons_update_visibility (PhotosPreviewNavButtons *self)
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
   GtkTreeIter iter;
   GtkTreeIter tmp;
+  gboolean enable_next = FALSE;
+  gboolean enable_prev = FALSE;
 
   if (priv->model == NULL
       || priv->current_path == NULL
       || !priv->visible
       || !gtk_tree_model_get_iter (priv->model, &iter, priv->current_path))
     {
-      photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
-      photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+      enable_prev = FALSE;
+      enable_next = FALSE;
       photos_preview_nav_buttons_fade_out_button (self, priv->toolbar_widget);
-      return;
+      goto out;
     }
 
   photos_preview_nav_buttons_fade_in_button (self, priv->toolbar_widget);
 
   tmp = iter;
-  if (gtk_tree_model_iter_previous (priv->model, &tmp))
-      photos_preview_nav_buttons_fade_in_button (self, priv->prev_widget);
-  else
-      photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
+  enable_prev = gtk_tree_model_iter_previous (priv->model, &tmp);
 
   tmp = iter;
-  if (gtk_tree_model_iter_next (priv->model, &tmp))
-      photos_preview_nav_buttons_fade_in_button (self, priv->next_widget);
-  else
-      photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+  enable_next = gtk_tree_model_iter_next (priv->model, &tmp);
 
   if (!priv->hover)
     photos_preview_nav_buttons_queue_auto_hide (self);
+
+ out:
+  g_object_set (self, "enable-next", enable_next, "enable-previous", enable_prev, NULL);
 }
 
 
@@ -283,6 +296,30 @@ photos_preview_nav_buttons_motion_notify (PhotosPreviewNavButtons *self)
 }
 
 
+static void
+photos_preview_nav_buttons_notify_enable_next (PhotosPreviewNavButtons *self)
+{
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  if (priv->enable_next)
+    photos_preview_nav_buttons_fade_in_button (self, priv->next_widget);
+  else
+    photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
+}
+
+
+static void
+photos_preview_nav_buttons_notify_enable_previous (PhotosPreviewNavButtons *self)
+{
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  if (priv->enable_prev)
+    photos_preview_nav_buttons_fade_in_button (self, priv->prev_widget);
+  else
+    photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
+}
+
+
 static void
 photos_preview_nav_buttons_set_active_path (PhotosPreviewNavButtons *self)
 {
@@ -305,22 +342,6 @@ photos_preview_nav_buttons_set_active_path (PhotosPreviewNavButtons *self)
 }
 
 
-static void
-photos_preview_nav_buttons_next_clicked (PhotosPreviewNavButtons *self)
-{
-  gtk_tree_path_next (self->priv->current_path);
-  photos_preview_nav_buttons_set_active_path (self);
-}
-
-
-static void
-photos_preview_nav_buttons_prev_clicked (PhotosPreviewNavButtons *self)
-{
-  gtk_tree_path_prev (self->priv->current_path);
-  photos_preview_nav_buttons_set_active_path (self);
-}
-
-
 static void
 photos_preview_nav_buttons_dispose (GObject *object)
 {
@@ -357,16 +378,9 @@ photos_preview_nav_buttons_constructed (GObject *object)
   GtkWidget *button;
   GtkWidget *image;
   GtkWidget *toolbar;
-  gboolean is_rtl;
-  const gchar *next_icon_name;
-  const gchar *prev_icon_name;
 
   G_OBJECT_CLASS (photos_preview_nav_buttons_parent_class)->constructed (object);
 
-  is_rtl = (gtk_widget_get_direction (priv->preview_view) == GTK_TEXT_DIR_RTL);
-  prev_icon_name = is_rtl ? PHOTOS_ICON_GO_NEXT_SYMBOLIC : PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC;
-  next_icon_name = is_rtl ? PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC : PHOTOS_ICON_GO_NEXT_SYMBOLIC;
-
   priv->prev_widget = gtk_revealer_new ();
   gtk_widget_set_halign (priv->prev_widget, GTK_ALIGN_START);
   gtk_widget_set_margin_start (priv->prev_widget, 30);
@@ -375,7 +389,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_revealer_set_transition_type (GTK_REVEALER (priv->prev_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
   gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay), priv->prev_widget);
 
-  image = gtk_image_new_from_icon_name (prev_icon_name, GTK_ICON_SIZE_INVALID);
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_GO_PREVIOUS_SYMBOLIC, GTK_ICON_SIZE_INVALID);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
 
   button = gtk_button_new ();
@@ -385,7 +399,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_container_add (GTK_CONTAINER (priv->prev_widget), button);
   g_signal_connect_swapped (button,
                             "clicked",
-                            G_CALLBACK (photos_preview_nav_buttons_prev_clicked),
+                            G_CALLBACK (photos_preview_nav_buttons_previous),
                             self);
   g_signal_connect_swapped (button,
                             "enter-notify-event",
@@ -404,7 +418,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_revealer_set_transition_type (GTK_REVEALER (priv->next_widget), GTK_REVEALER_TRANSITION_TYPE_CROSSFADE);
   gtk_overlay_add_overlay (GTK_OVERLAY (priv->overlay), priv->next_widget);
 
-  image = gtk_image_new_from_icon_name (next_icon_name, GTK_ICON_SIZE_INVALID);
+  image = gtk_image_new_from_icon_name (PHOTOS_ICON_GO_NEXT_SYMBOLIC, GTK_ICON_SIZE_INVALID);
   gtk_image_set_pixel_size (GTK_IMAGE (image), 16);
 
   button = gtk_button_new ();
@@ -414,7 +428,7 @@ photos_preview_nav_buttons_constructed (GObject *object)
   gtk_container_add (GTK_CONTAINER (priv->next_widget), button);
   g_signal_connect_swapped (button,
                             "clicked",
-                            G_CALLBACK (photos_preview_nav_buttons_next_clicked),
+                            G_CALLBACK (photos_preview_nav_buttons_next),
                             self);
   g_signal_connect_swapped (button,
                             "enter-notify-event",
@@ -460,6 +474,29 @@ photos_preview_nav_buttons_constructed (GObject *object)
 }
 
 
+static void
+photos_preview_nav_buttons_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec)
+{
+  PhotosPreviewNavButtons *self = PHOTOS_PREVIEW_NAV_BUTTONS (object);
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  switch (prop_id)
+    {
+    case PROP_ENABLE_NEXT:
+      g_value_set_boolean (value, priv->enable_next);
+      break;
+
+    case PROP_ENABLE_PREVIOUS:
+      g_value_set_boolean (value, priv->enable_prev);
+      break;
+
+    default:
+      G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
+    }
+}
+
+
 static void
 photos_preview_nav_buttons_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec)
 {
@@ -468,6 +505,14 @@ photos_preview_nav_buttons_set_property (GObject *object, guint prop_id, const G
 
   switch (prop_id)
     {
+    case PROP_ENABLE_NEXT:
+      priv->enable_next = g_value_get_boolean (value);
+      break;
+
+    case PROP_ENABLE_PREVIOUS:
+      priv->enable_prev = g_value_get_boolean (value);
+      break;
+
     case PROP_OVERLAY:
       priv->overlay = GTK_WIDGET (g_value_dup_object (value));
       break;
@@ -496,6 +541,17 @@ photos_preview_nav_buttons_init (PhotosPreviewNavButtons *self)
                             "active-changed",
                             G_CALLBACK (photos_preview_nav_buttons_active_changed),
                             self);
+
+  priv->action = PHOTOS_PREVIEW_ACTION_NONE;
+
+  g_signal_connect (self,
+                    "notify::enable-next",
+                    G_CALLBACK (photos_preview_nav_buttons_notify_enable_next),
+                    NULL);
+  g_signal_connect (self,
+                    "notify::enable-previous",
+                    G_CALLBACK (photos_preview_nav_buttons_notify_enable_previous),
+                    NULL);
 }
 
 
@@ -507,8 +563,25 @@ photos_preview_nav_buttons_class_init (PhotosPreviewNavButtonsClass *class)
   object_class->constructed = photos_preview_nav_buttons_constructed;
   object_class->dispose = photos_preview_nav_buttons_dispose;
   object_class->finalize = photos_preview_nav_buttons_finalize;
+  object_class->get_property = photos_preview_nav_buttons_get_property;
   object_class->set_property = photos_preview_nav_buttons_set_property;
 
+  g_object_class_install_property (object_class,
+                                   PROP_ENABLE_NEXT,
+                                   g_param_spec_boolean ("enable-next",
+                                                         "Enable next",
+                                                         "Allow moving to the next item",
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
+
+  g_object_class_install_property (object_class,
+                                   PROP_ENABLE_PREVIOUS,
+                                   g_param_spec_boolean ("enable-previous",
+                                                         "Enable previous",
+                                                         "Allow moving to the previous item",
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
+
   g_object_class_install_property (object_class,
                                    PROP_OVERLAY,
                                    g_param_spec_object ("overlay",
@@ -524,6 +597,17 @@ photos_preview_nav_buttons_class_init (PhotosPreviewNavButtonsClass *class)
                                                         "The widget used for showing the preview",
                                                         PHOTOS_TYPE_PREVIEW_VIEW,
                                                         G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE));
+
+  signals[ACTIVATED] = g_signal_new ("activated",
+                                     G_TYPE_FROM_CLASS (class),
+                                     G_SIGNAL_RUN_LAST,
+                                     G_STRUCT_OFFSET (PhotosPreviewNavButtonsClass, activated),
+                                     NULL, /*accumulator */
+                                     NULL, /*accu_data */
+                                     g_cclosure_marshal_generic,
+                                     G_TYPE_NONE,
+                                     1,
+                                     PHOTOS_TYPE_PREVIEW_ACTION);
 }
 
 
@@ -534,15 +618,57 @@ photos_preview_nav_buttons_new (PhotosPreviewView *preview_view, GtkOverlay *ove
 }
 
 
+PhotosPreviewAction
+photos_preview_nav_buttons_get_action (PhotosPreviewNavButtons *self)
+{
+  return self->priv->action;
+}
+
+
 void
 photos_preview_nav_buttons_hide (PhotosPreviewNavButtons *self)
 {
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
+  priv->action = PHOTOS_PREVIEW_ACTION_NONE;
   priv->visible = FALSE;
   photos_preview_nav_buttons_fade_out_button (self, priv->prev_widget);
   photos_preview_nav_buttons_fade_out_button (self, priv->next_widget);
   photos_preview_nav_buttons_fade_out_button (self, priv->toolbar_widget);
+
+  g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
+}
+
+
+void
+photos_preview_nav_buttons_next (PhotosPreviewNavButtons *self)
+{
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  if (!priv->enable_next)
+    return;
+
+  priv->action = PHOTOS_PREVIEW_ACTION_NEXT;
+  gtk_tree_path_next (priv->current_path);
+  photos_preview_nav_buttons_set_active_path (self);
+
+  g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
+}
+
+
+void
+photos_preview_nav_buttons_previous (PhotosPreviewNavButtons *self)
+{
+  PhotosPreviewNavButtonsPrivate *priv = self->priv;
+
+  if (!priv->enable_prev)
+    return;
+
+  priv->action = PHOTOS_PREVIEW_ACTION_PREVIOUS;
+  gtk_tree_path_prev (priv->current_path);
+  photos_preview_nav_buttons_set_active_path (self);
+
+  g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
 
 
@@ -571,6 +697,9 @@ photos_preview_nav_buttons_show (PhotosPreviewNavButtons *self)
 {
   PhotosPreviewNavButtonsPrivate *priv = self->priv;
 
+  priv->action = PHOTOS_PREVIEW_ACTION_NONE;
   priv->visible = TRUE;
   photos_preview_nav_buttons_update_visibility (self);
+
+  g_signal_emit (self, signals[ACTIVATED], 0, priv->action);
 }
