@@ -28,12 +28,16 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
+#include <gio/gio.h>
+
+#include "photos-base-manager.h"
 #include "photos-enums.h"
+#include "photos-filterable.h"
 #include "photos-item-manager.h"
 #include "photos-marshalers.h"
 #include "photos-mode-controller.h"
 #include "photos-query-builder.h"
-#include "photos-source-manager.h"
+#include "photos-search-context.h"
 #include "photos-tracker-controller.h"
 #include "photos-tracker-queue.h"
 
@@ -258,14 +262,11 @@ photos_tracker_controller_refresh_for_source (PhotosTrackerController *self)
 
   if (priv->current_query->source != NULL)
     {
-      gchar *id;
-
-      g_object_get (priv->current_query->source, "id", &id, NULL);
+      const gchar *id;
 
+      id = photos_filterable_get_id (PHOTOS_FILTERABLE (priv->current_query->source));
       if (g_strcmp0 (id, PHOTOS_SOURCE_STOCK_ALL) == 0)
         photos_tracker_controller_refresh_internal (self, PHOTOS_TRACKER_REFRESH_FLAGS_NONE);
-
-      g_free (id);
     }
 
   priv->refresh_pending = FALSE;
@@ -373,14 +374,19 @@ static void
 photos_tracker_controller_init (PhotosTrackerController *self)
 {
   PhotosTrackerControllerPrivate *priv;
+  GApplication *app;
+  PhotosSearchContextState *state;
 
   self->priv = photos_tracker_controller_get_instance_private (self);
   priv = self->priv;
 
+  app = g_application_get_default ();
+  state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
+
   priv->cancellable = g_cancellable_new ();
   priv->item_mngr = photos_item_manager_dup_singleton ();
 
-  priv->src_mngr = photos_source_manager_dup_singleton ();
+  priv->src_mngr = g_object_ref (state->src_mngr);
   g_signal_connect_swapped (priv->src_mngr,
                             "object-added",
                             G_CALLBACK (photos_tracker_controller_source_object_added_removed),
