@@ -35,7 +35,11 @@
 #include <libgd/gd.h>
 
 #include "photos-application.h"
+#include "photos-facebook-item.h"
+#include "photos-flickr-item.h"
+#include "photos-local-item.h"
 #include "photos-query.h"
+#include "photos-source.h"
 #include "photos-tracker-queue.h"
 #include "photos-utils.h"
 
@@ -70,7 +74,7 @@ photos_utils_create_collection_icon (gint base_size, GList *pixbufs)
   tile_size = (base_size - (3 * padding)) / 2;
 
   context = gtk_style_context_new ();
-  gtk_style_context_add_class (context, "documents-collection-icon");
+  gtk_style_context_add_class (context, "photos-collection-icon");
 
   path = gtk_widget_path_new ();
   gtk_widget_path_append_type (path, GTK_TYPE_ICON_VIEW);
@@ -364,6 +368,41 @@ photos_utils_dot_dir (void)
 }
 
 
+void
+photos_utils_ensure_builtins (void)
+{
+  static gsize once_init_value = 0;
+
+  photos_utils_ensure_extension_points ();
+
+  if (g_once_init_enter (&once_init_value))
+    {
+      g_type_ensure (PHOTOS_TYPE_FACEBOOK_ITEM);
+      g_type_ensure (PHOTOS_TYPE_FLICKR_ITEM);
+      g_type_ensure (PHOTOS_TYPE_LOCAL_ITEM);
+
+      g_once_init_leave (&once_init_value, 1);
+    }
+}
+
+
+void
+photos_utils_ensure_extension_points (void)
+{
+  static gsize once_init_value = 0;
+
+  if (g_once_init_enter (&once_init_value))
+    {
+      GIOExtensionPoint *extension_point;
+
+      extension_point = g_io_extension_point_register (PHOTOS_BASE_ITEM_EXTENSION_POINT_NAME);
+      g_io_extension_point_set_required_type (extension_point, PHOTOS_TYPE_BASE_ITEM);
+
+      g_once_init_leave (&once_init_value, 1);
+    }
+}
+
+
 GQuark
 photos_utils_error_quark (void)
 {
@@ -593,6 +632,21 @@ photos_utils_get_pixbuf_savable_formats (void)
   return write_list;
 }
 
+
+const gchar *
+photos_utils_get_provider_name (PhotosBaseManager *src_mngr, PhotosBaseItem *item)
+{
+  PhotosSource *source;
+  const gchar *name;
+  const gchar *resource_urn;
+
+  resource_urn = photos_base_item_get_resource_urn (item);
+  source = PHOTOS_SOURCE (photos_base_manager_get_object_by_id (src_mngr, resource_urn));
+  name = photos_source_get_name (source);
+  return name;
+}
+
+
 GtkBorder *
 photos_utils_get_thumbnail_frame_border (void)
 {
